PAWpySeed: pawpyseed.analysis.defect_composition.BulkCharacter Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Static Public Member Functions | Public Attributes | List of all members
pawpyseed.analysis.defect_composition.BulkCharacter Class Reference
Inheritance diagram for pawpyseed.analysis.defect_composition.BulkCharacter:
[legend]
Collaboration diagram for pawpyseed.analysis.defect_composition.BulkCharacter:
[legend]

## Public Member Functions
def | __init__ (self, structure, data, energy_levels=None, dos=None, vbm=None, cbm=None)
def | as_dict (self)
def | from_dict (cls, data)
def | plot (self, name, title=None, spinpol=False)
Public Member Functions inherited from pawpyseed.analysis.defect_composition.PawpyData
def | __init__ (self, structure, data, dos=None, vbm=None, cbm=None)
def | set_band_properties (vbm, cbm)
def | as_dict (self)
def | write_yaml (self, filename)
def | from_dict (cls, data)
def | from_yaml (cls, filename)

## Static Public Member Functions
def | makeit (generator)

## Public Attributes
| energy_levels
Public Attributes inherited from pawpyseed.analysis.defect_composition.PawpyData
| energies
| densities
| efermi
| structure
| data
| cbm
| vbm
| bandgap

## Detailed Description

    The data member for the BulkCharacter is dictionary of form
    {band_index : (v, c)}, where v and c are the valence and
    conduction character of the band, respectively.

## Constructor & Destructor Documentation

def pawpyseed.analysis.defect_composition.BulkCharacter.__init__ | ( |  | self,
|  |  | structure,
|  |  | data,
|  |  | energy_levels = `None`,
|  |  | dos = `None`,
|  |  | vbm = `None`,
|  |  | cbm = `None`
| ) |  |

    Arguments:
        structure (pymatgen.core.structure.Structure): crystal structure
        energy_levels (list of list): list of energy levels at the different
    k-points and spins in each band. Returned by Projector.defect_band_analysis
        data: {band_index : (v, c)}, where v and c are the valence and
    conduction character of the band, respectively.
    Returned by Projector.defect_band_analysis
        dos (pymatgen.electronic_structure.dos.DOS or list, None): A pymatgen
    density of states or a list containing: 1) energies, 2) density
    of states values at those energies, 3) the Fermi level.
        vbm (float, None): valence band maximum
        cbm (float, None): conduction band minimum

## Member Function Documentation

def pawpyseed.analysis.defect_composition.BulkCharacter.as_dict | ( |  | self | ) |

def pawpyseed.analysis.defect_composition.BulkCharacter.from_dict | ( |  | cls,
|  |  | data
| ) |  |

    Takes the dictionary--data--and
    returns a PawpyData instance.

def pawpyseed.analysis.defect_composition.BulkCharacter.makeit | ( |  | generator | ) |
| static

def pawpyseed.analysis.defect_composition.BulkCharacter.plot | ( |  | self,
|  |  | name,
|  |  | title = `None`,
|  |  | spinpol = `False`
| ) |  |

    Plot the bulk character data. If the energy levels are available,
    those are plotted for reference. Otherwise, if the dos is available,
    it is plotted for reference.

    Arguments:
        name (str): Name of the file to which the plot is saved.
    Spaces will be replaced with underscores.
        title (str, None): Title of the plot. Defaults to name,
    so it is recommended to set this.
        spinpol (bool, False): Show the spin polarized valence
    and conduction character. Only works if the VASP
    calculation was spin polarized

## Member Data Documentation

pawpyseed.analysis.defect_composition.BulkCharacter.energy_levels

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/analysis/defect_composition.py